// Copyright (c) 2015, Anaren Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
// 1. Redistributions of source code must retain the above copyright notice, this
//    list of conditions and the following disclaimer.
// 2. Redistributions in binary form must reproduce the above copyright notice,
//    this list of conditions and the following disclaimer in the documentation
//    and/or other materials provided with the distribution.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
// ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
// (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
// LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
// ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
// SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//
// The views and conclusions contained in the software and documentation are those
// of the authors and should not be interpreted as representing official policies,
// either expressed or implied, of the FreeBSD Project.

#ifndef TMP112_H
#define TMP112_H

#include "../i2c/i2c.h"
#include "types.h"

#define uint8 UINT8
#define uint16 UINT16

#define TMP112_SLAVE_BASE_ADDR      0x48
#define TMP112_TAMBIENT_REG_ADDR    0x00
#define TMP112_CONFIG_REG_ADDR      0x01
#define TMP112_TLOW_REG_ADDR      	0x02
#define TMP112_THIGH_REG_ADDR      	0x03

/**
Issue a software reset to the sensor and puts it into shutdoen mode.
@param id device ID (0 to 3) on i2c bus
*/
void TMP112_SoftwareReset(uint8 id);

/**
Perform a single conversion and read the ambient (die) temperature.
@param id device ID (0 to 3) on i2c bus
@return temperature of the TMP112 die in Celsius
*/
char TMP112_GetAmbientTemperature(uint8 id);


#endif  /* TMP112_H */
